class IncorrectAPIFormatException(Exception):
    pass

class PageNotFoundException(Exception):
    pass

class UnsupportedLanguageException(Exception):
    pass

class TitleNotFound(Exception):
    pass
